import React from 'react';
import { Image, ImageURISource, StyleSheet, View } from 'react-native';

export type IllustrationProps = {
  primaryColor: string;
  cardImage: ImageURISource;
};
const Illustration = ({ primaryColor, cardImage }: IllustrationProps) => (
  <View style={styles.container}>
    <Image
      source={require('./../assets/OldCard.png')}
      style={styles.oldCard}
      resizeMode={'contain'}
    />
    <View style={styles.cardContainer}>
      <Image
        source={require('./../assets/arrow.png')}
        style={{ tintColor: primaryColor }}
      />
    </View>
    <View>
      <Image style={styles.card} resizeMode={'contain'} source={cardImage} />
      <Image
        style={[styles.image, { top: -15, left: -20 }]}
        source={require('./../assets/netflix.png')}
      />
      <Image
        style={[styles.image, { right: 10, top: -20 }]}
        source={require('./../assets/starbucks.png')}
      />
      <Image
        style={[styles.image, { right: -15, bottom: -30 }]}
        source={require('./../assets/amazon.png')}
      />
      <Image
        style={[styles.image, { bottom: -35 }]}
        source={require('./../assets/lyft.png')}
      />
    </View>
  </View>
);
const styles = StyleSheet.create({
  image: {
    position: 'absolute',
  },
  container: {
    width: '90%',
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    paddingVertical: 20,
    marginBottom: 20,
  },
  oldCard: {
    width: 105,
    height: 70,
    transform: [{ rotate: '-3deg' }],
    borderRadius: 10,
  },
  cardContainer: {
    flex: 1,
    margin: 10,
    justifyContent: 'center',
    alignItems: 'center',
  },
  card: {
    width: 105,
    height: 70,
    transform: [{ rotate: '3deg' }],
    borderRadius: 10,
  },
});
export default Illustration;
