import React from 'react';
import { ImageURISource, Modal, Pressable, StyleSheet, Text, View } from 'react-native';
import Illustration from './Illustration';

export type OnBoardingModalProps = {
  onClose: () => void;
  onDone: () => void;
  isVisible: boolean;
  cardImage: ImageURISource;
  primaryColor: string;
  textColor: string;
}
const OnBoardingModal = ({ onDone, onClose, isVisible, cardImage, primaryColor, textColor }: OnBoardingModalProps) => (
  <Modal visible={isVisible} transparent={true} animationType='slide'
         style={styles.modal}>
    <View style={styles.container}>

      <View style={styles.contentContainer}>
        <View style={{
          marginTop: -20,
          width: '90%',
        }}>
          <Illustration primaryColor={primaryColor} cardImage={cardImage} />
        </View>
        <View style={{
          marginTop: 40,
        }}><Text style={styles.heading}>Welcome!</Text></View>
        <Text style={styles.subHeading}>Get started by transferring all your accounts to your new Chime card. It’s
          simple and takes about 5-10
          minutes.</Text>
        <View style={{
          marginTop: 40,
          width: '100%',
        }}>
          <Pressable style={[{
            backgroundColor: primaryColor,
          }, styles.button]} onPress={onDone}>
            <Text style={[{
              color: textColor,
            }, styles.textButton]}>
              Done
            </Text>
          </Pressable>
        </View>
        <View style={{
          marginTop: 12,
          width: '100%',
        }}>
          <View style={[{
            backgroundColor: primaryColor,
            opacity: 0.2,
          }, styles.button]}>
            <Text style={[{
              color: primaryColor,
            }, styles.textButton]}>Maybe Later</Text>
          </View>
          <Pressable onPress={onClose} style={{position: 'absolute', top: 0, right: 0, left: 0, bottom: 0, justifyContent: 'center', alignItems: 'center'}}>
            <Text style={[{
              color: primaryColor,
            }, styles.textButton]}>Maybe Later</Text>
          </Pressable>
        </View>
      </View>
    </View>
  </Modal>
);

const styles = StyleSheet.create({
  modal: { flex: 1, justifyContent: 'center', alignItems: 'center' },
  container: {
    backgroundColor: '#fff',
    justifyContent: 'center',
    alignItems: 'center',
    width: '100%',
    flex: 1,
  },
  contentContainer: {
    padding: 20,
    justifyContent: 'center',
    alignItems: 'center',
    width: '100%',
    borderRadius: 10,
  },
  heading: {
    fontWeight: '500',
    fontSize: 28,
    lineHeight: 36,
    alignItems: 'center',
    color: '#272727',
  },
  subHeading: {
    fontWeight: '400',
    fontSize: 15,
    lineHeight: 20,
    alignItems: 'center',
    textAlign: 'center',
    color: '#272727',
  },
  button: {
    padding: 20,
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 100,
  },
  textButton: {
    fontWeight: '600',
    fontSize: 18,
    lineHeight: 24,
    alignItems: 'center',
  },
  box: {
    width: 60,
    height: 60,
    marginVertical: 20,
  },
});

export default OnBoardingModal;
